==> client-sdk-react-1.5.0.tgz: package/src/store/transcript/transcriptSlice.ts <==
import { createSlice, PayloadAction } from '@reduxjs/toolkit'
import { RootState } from '../../app/store'
import { ParticipantTranscriptModel, SessionTranscriptModel } from './models'
import { TranscriptionReceivedAction } from './actionModels'

const initialState: SessionTranscriptModel = {
  transcriptionServiceIsEnabled: false,
  transcriptionServiceIsLoading: false,
  transcriptionInProgress: false,
  transcripts: {},
}

export const transcriptSlice = createSlice({
  name: 'transcript',
  initialState,
  reducers: {
    transcriptionReceived: (state, action: PayloadAction<TranscriptionReceivedAction>) => {
      const { participantId, transcriptionResults } = action.payload
      if (!state.transcripts[participantId]) {
        state.transcripts[participantId] = { finalTranscripts: [], partialTranscript: null }
      }
      const participantTranscripts = state.transcripts[participantId]
      for (const transcriptionResult of transcriptionResults) {
        if (transcriptionResult.isFinal) {
          participantTranscripts.finalTranscripts.push(transcriptionResult)
          participantTranscripts.partialTranscript = null
        } else {
          participantTranscripts.partialTranscript = transcriptionResult
        }
      }
    },
    setTranscriptionServiceEnabled: (state, action: PayloadAction<boolean>) => {
      state.transcriptionServiceIsEnabled = action.payload
    },
    setTranscriptionServiceIsLoading: (state, action: PayloadAction<boolean>) => {
      state.transcriptionServiceIsLoading = action.payload
    },
    setTranscriptionInProgress: (state, action: PayloadAction<boolean>) => {
      const inProgress = action.payload
      state.transcriptionInProgress = inProgress
      if (!inProgress) {
        for (const transcript of Object.values(state.transcripts)) {
          transcript.partialTranscript = null
        }
      }
    },
    clearTranscription: (state) => {
      state.transcripts = {}
      state.transcriptionServiceIsEnabled = false
    },
  },
})

export const {
  clearTranscription,
  setTranscriptionServiceEnabled,
  setTranscriptionServiceIsLoading,
  setTranscriptionInProgress,
  transcriptionReceived,
} = transcriptSlice.actions

export const selectTranscriptionServiceIsEnabled = (state: RootState) => state.transcript.transcriptionServiceIsEnabled
export const selectTranscriptionServiceIsLoading = (state: RootState) => state.transcript.transcriptionServiceIsLoading
export const selectTranscriptionInProgress = (state: RootState) => state.transcript.transcriptionInProgress
export const selectTranscripts = (state: RootState) => state.transcript.transcripts

export const selectParticipantTranscripts = (state: RootState, participantId: string): ParticipantTranscriptModel => {
  const { transcripts } = state.transcript
  if (!transcripts[participantId]) {
    return { finalTranscripts: [], partialTranscript: null }
  }
  return transcripts[participantId]
}

export default transcriptSlice.reducer

==> client-sdk-react-1.6.0.tgz: package/src/store/transcript/transcriptSlice.ts <==
import { createSlice, PayloadAction } from '@reduxjs/toolkit'
import { RootState } from '../../app/store'
import { ParticipantTranscriptModel, SessionTranscriptModel } from './models'
import { TranscriptionReceivedAction } from './actionModels'

const initialState: SessionTranscriptModel = {
  transcriptionServiceIsEnabled: false,
  transcriptionServiceIsLoading: false,
  transcriptionInProgress: false,
  transcripts: {},
}

export const transcriptSlice = createSlice({
  name: 'transcript',
  initialState,
  reducers: {
    transcriptionReceived: (state, action: PayloadAction<TranscriptionReceivedAction>) => {
      const { participantId, transcriptionResult } = action.payload
      if (!state.transcripts[participantId]) {
        state.transcripts[participantId] = { finalTranscripts: [], partialTranscript: null }
      }
      const participantTranscripts = state.transcripts[participantId]
      if (transcriptionResult.isFinal) {
        participantTranscripts.finalTranscripts.push(transcriptionResult)
        participantTranscripts.partialTranscript = null
      } else {
        participantTranscripts.partialTranscript = transcriptionResult
      }
    },
    setTranscriptionServiceEnabled: (state, action: PayloadAction<boolean>) => {
      state.transcriptionServiceIsEnabled = action.payload
    },
    setTranscriptionServiceIsLoading: (state, action: PayloadAction<boolean>) => {
      state.transcriptionServiceIsLoading = action.payload
    },
    setTranscriptionInProgress: (state, action: PayloadAction<boolean>) => {
      const inProgress = action.payload
      state.transcriptionInProgress = inProgress
      if (!inProgress) {
        for (const transcript of Object.values(state.transcripts)) {
          transcript.partialTranscript = null
        }
      }
    },
    clearTranscription: (state) => {
      state.transcripts = {}
      state.transcriptionServiceIsEnabled = false
    },
  },
})

export const {
  clearTranscription,
  setTranscriptionServiceEnabled,
  setTranscriptionServiceIsLoading,
  setTranscriptionInProgress,
  transcriptionReceived,
} = transcriptSlice.actions

export const selectTranscriptionServiceIsEnabled = (state: RootState) => state.transcript.transcriptionServiceIsEnabled
export const selectTranscriptionServiceIsLoading = (state: RootState) => state.transcript.transcriptionServiceIsLoading
export const selectTranscriptionInProgress = (state: RootState) => state.transcript.transcriptionInProgress
export const selectTranscripts = (state: RootState) => state.transcript.transcripts

export const selectParticipantTranscripts = (state: RootState, participantId: string): ParticipantTranscriptModel => {
  const { transcripts } = state.transcript
  if (!transcripts[participantId]) {
    return { finalTranscripts: [], partialTranscript: null }
  }
  return transcripts[participantId]
}

export default transcriptSlice.reducer
